@@ -268,8 +268,6 @@ def convert_value(field, value, context=None):
         format_ = context.get('date_format', '%x') + ' %X'
         try:
             dt = date_parse(value, format_)
-            if dt.time() == datetime.time.min:
-                return dt
             return untimezoned_date(dt)
         except ValueError:
             return
@@ -403,16 +401,17 @@ def test_convert_datetime():
         'format': '"%H:%M:%S"',
         }
     for value, result in (
-            ('12/04/2002', datetime.datetime(2002, 12, 4)),
+            ('12/04/2002', untimezoned_date(datetime.datetime(2002, 12, 4))),
             ('12/04/2002 12:30:00', untimezoned_date(
                     datetime.datetime(2002, 12, 4, 12, 30))),
-            ('02/03/04', datetime.datetime(2004, 2, 3)),
+            ('02/03/04', untimezoned_date(datetime.datetime(2004, 2, 3))),
             ('02/03/04 05:06:07', untimezoned_date(
                     datetime.datetime(2004, 2, 3, 5, 6, 7))),
             ('test', None),
             (None, None),
             ):
-        assert convert_value(field, value) == result
+        assert convert_value(field, value) == result, (value,
+            convert_value(field, value), result)
 
 
 def test_convert_date():
@@ -490,12 +489,12 @@ def format_value(field, value, target=None, context=None):
         if not value:
             return ''
         format_ = context.get('date_format', '%x') + ' ' + time_format(field)
-        if (not isinstance(value, datetime.datetime)
-                or value.time() == datetime.time.min):
-            format_ = '%x'
-            time = value
+        if not isinstance(value, datetime.datetime):
+            time = datetime.datetime.combine(value, datetime.time.min)
         else:
             time = timezoned_date(value)
+        if time.time() == datetime.time.min:
+            format_ = '%x'
         return datetime_strftime(time, format_)
 
     def format_date():
@@ -628,7 +627,7 @@ def test_format_datetime():
         }
     for value, result in (
             (datetime.date(2002, 12, 4), '12/04/2002'),
-            (datetime.datetime(2002, 12, 4), '12/04/2002'),
+            (untimezoned_date(datetime.datetime(2002, 12, 4)), '12/04/2002'),
             (untimezoned_date(datetime.datetime(2002, 12, 4, 12, 30)),
                 '"12/04/2002 12:30:00"'),
             (False, ''),
@@ -915,7 +914,24 @@ class DomainParser(object):
                         or isinstance(clause[0], (list, tuple)))
                     and all(isinstance(c, (list, tuple)) for c in clause[1:])):
                 return self.stringable(clause)
-            if clause[0] in self.fields or clause[0] == 'rec_name':
+            name, _, value = clause[:3]
+            if name.endswith('.rec_name'):
+                name = name[:-len('.rec_name')]
+            if name in self.fields:
+                field = self.fields[name]
+                if field['type'] in {
+                        'many2one', 'one2one', 'one2many', 'many2many'}:
+                    if field['type'] == 'many2one':
+                        types = (str, type(None))
+                    else:
+                        types = str
+                    if isinstance(value, (list, tuple)):
+                        return all(isinstance(v, types) for v in value)
+                    else:
+                        return isinstance(value, types)
+                else:
+                    return True
+            elif name == 'rec_name':
                 return True
             return False
 
@@ -1203,6 +1219,14 @@ def test_stringable():
                 'string': 'Name',
                 'type': 'char',
                 },
+            'relation': {
+                'string': 'Relation',
+                'type': 'many2one',
+                },
+            'relations': {
+                'string': 'Relations',
+                'type': 'many2many',
+                },
             })
     valid = ('name', '=', 'Doe')
     invalid = ('surname', '=', 'John')
@@ -1212,6 +1236,13 @@ def test_stringable():
     assert not dom.stringable(['AND', valid, invalid])
     assert dom.stringable([[valid]])
     assert not dom.stringable([[valid], [invalid]])
+    assert dom.stringable([('relation', '=', None)])
+    assert dom.stringable([('relation', '=', "Foo")])
+    assert dom.stringable([('relation.rec_name', '=', "Foo")])
+    assert not dom.stringable([('relation', '=', 1)])
+    assert dom.stringable([('relations', '=', "Foo")])
+    assert dom.stringable([('relations', 'in', ["Foo"])])
+    assert not dom.stringable([('relations', 'in', [42])])
 
 
 def test_string():
