@@ -257,6 +257,9 @@ class Record(SignalEvent):
             if field.name not in self.modified_fields and self.id >= 0:
                 continue
             value[name] = field.get(self)
+            # Sending an empty x2MField breaks ModelFieldAccess.check
+            if isinstance(field, fields.O2MField) and not value[name]:
+                del value[name]
         return value
 
     def get_eval(self):
@@ -506,6 +509,12 @@ class Record(SignalEvent):
     def expr_eval(self, expr):
         if not isinstance(expr, basestring):
             return expr
+        if not expr:
+            return
+        elif expr == '[]':
+            return []
+        elif expr == '{}':
+            return {}
         ctx = rpc.CONTEXT.copy()
         ctx['context'] = ctx.copy()
         ctx['context'].update(self.get_context())
